@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/* Copyright 2008,2009,2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -345,6 +345,12 @@ KGpgKeyNode::compareId(const QString &other) const
 			Qt::CaseInsensitive) == 0);
 }
 
+bool
+KGpgKeyNode::canEncrypt() const
+{
+	return ((m_key->keytype() & KgpgCore::SKT_ENCRYPTION) != 0);
+}
+
 void
 KGpgKeyNode::expand()
 {
